@@ -1,6 +1,6 @@
 ;;; weather.el --- Weather Report -*- coding: iso-2022-3-compatible -*-
 
-;; Copyright (C) 1999-2003 Kenichi OKADA <okada@opaopa.org>
+;; Copyright (C) 1999-2006 Kenichi OKADA <okada@opaopa.org>
 
 ;; Author: Kenichi OKADA <okada@opaopa.org>
 ;;	Yuuichi Teranishi <teranisi@gohome.org>
@@ -22,7 +22,7 @@
 
 ;;; Commentary:
 
-;; from http://www.imoc.co.jp/week.htm
+;; from http://www.imocwx.com/week.htm
 ;;
 ;; usage:
 ;;
@@ -52,11 +52,11 @@
   (defun-maybe Meadow-version ()))
 
 (product-provide 'weather-version
-  (product-define "Weather" nil '(0 32)))
+  (product-define "Weather" nil '(0 33)))
 
 (defvar weather-insert-user-agent nil)
 
-(defvar weather-server "www.imoc.co.jp")
+(defvar weather-server "www.imocwx.com")
 (defvar weather-port 80)
 (defvar weather-coding-system (static-if (boundp 'MULE) '*sjis* 'shift_jis))
 
